@@ -60,10 +60,10 @@ use LWP::UserAgent;
 use List::Util qw(pairs any);
 use MIME::Base64;
 use POSIX::strptime qw(strptime);
-use Scalar::Util qw(reftype);
+use Scalar::Util    qw(reftype);
 use Time::Local;
 
-use constant { ## no critic (ProhibitConstantPragma, Capitalization)
+use constant {  ## no critic (ProhibitConstantPragma, Capitalization)
   AWS_AVAILABILITY_ZONE_URL =>
     q{latest/meta-data/placement/availability-zone},
   AWS_CONTAINER_CREDENTIALS_URL    => q{http://169.254.170.2/},
@@ -98,14 +98,14 @@ use constant { ## no critic (ProhibitConstantPragma, Capitalization)
   X_AMZ_SSO_BEARER_TOKEN        => ':x-amz-sso_bearer_token',
 };
 
-our $VERSION = '1.1.18'; ## no critic (RequireInterpolationOfMetachars)
+our $VERSION = '1.1.19';  ## no critic (RequireInterpolation)
 
 our @EXPORT_OK
   = qw( create_passkey set_sso_credentials get_role_credentials );
 
 # we only log at debug level, create a default logger
 {
-  no strict 'refs'; ## no critic (ProhibitNoStrict)
+  no strict 'refs';  ## no critic (ProhibitNoStrict)
 
   *{'Amazon::Credentials::Logger::debug'} = sub {
     my ( $self, @message ) = @_;
@@ -146,7 +146,9 @@ sub new {
       carp <<'WARNING';
 WARNING: the encryption passkey has already been set. Resetting the
 passkey will require that you restore the original passkey if you are
-using more than one instance of Amazon::Credentials
+using more than one instance of Amazon::Credentials.
+
+To turn this warning off set 'no_passkey_warning' to a true value.
 WARNING
     }
 
@@ -156,6 +158,8 @@ WARNING
     if ( !$self->get_no_passkey_warning ) {
       carp <<'WARNING';
 WARNING: the encryption passkey has already been set. Using the previous passkey.
+
+To turn this warning off set 'no_passkey_warning' to a true value.
 WARNING
     }
 
@@ -1147,7 +1151,7 @@ sub set_sso_credentials {
       )
     ) {
 
-      $ENV{ $p->[1] } = sprintf '%s', $credentials->{ $p->[0] }; ## no critic (RequireLocalizedPunctuationVars)
+      $ENV{ $p->[1] } = sprintf '%s', $credentials->{ $p->[0] };  ## no critic (RequireLocalizedPunctuationVars)
     }
 
   }
@@ -1619,7 +1623,7 @@ or pass your SSO role name and account ID...
  
 =head1 VERSION
 
-This document reverse to verion 1.1.18 of
+This document reverse to verion 1.1.19 of
 L<Amazon::Credentials>.
 
 =head1 METHODS AND SUBROUTINES
@@ -2493,7 +2497,10 @@ debugging modes that you might pass to L<Amazon::Credentials>.
 
 Starting with version I<1.1.0> the L<Amazon::Credentials> will B<not>
 use the environment variable DEBUG to enable debugging! You must
-explicitly pass the debug flag in the constructor to enable debugging. This was done to prevent potential upstream modules that you might use who allow an environment variable to set debug mode to also inadvertantly trigger debug mode for L<Amazon::Credentials>.
+explicitly pass the debug flag in the constructor to enable
+debugging. This was done to prevent potential upstream modules that
+you might use who allow an environment variable to set debug mode to
+also inadvertantly trigger debug mode for L<Amazon::Credentials>.
 
 =head1 INCOMPATIBILITIES
 
